[Scummvm-cvs-logs] SF.net SVN: scummvm:[40524] scummvm/trunk/engines/sci

thebluegr at users.sourceforge.net thebluegr at users.sourceforge.net
Wed May 13 18:52:41 CEST 2009


Revision: 40524
          http://scummvm.svn.sourceforge.net/scummvm/?rev=40524&view=rev
Author:   thebluegr
Date:     2009-05-13 16:52:41 +0000 (Wed, 13 May 2009)

Log Message:
-----------
- Simplified SCI version detection a bit and clarified the different version feature flags (not used yet)
- Removed the version verification functions (they were only used for two specific cases, but the SCI executable reader is able to detect the exact SCI game version anyway, so there is no point in having these)
- Removed the empty GameFlags structure and replaced it with a 32-bit integer instead

Modified Paths:
--------------
    scummvm/trunk/engines/sci/detection.cpp
    scummvm/trunk/engines/sci/engine/game.cpp
    scummvm/trunk/engines/sci/engine/kevent.cpp
    scummvm/trunk/engines/sci/engine/kgraphics.cpp
    scummvm/trunk/engines/sci/engine/kmenu.cpp
    scummvm/trunk/engines/sci/engine/kpathing.cpp
    scummvm/trunk/engines/sci/engine/savegame.cpp
    scummvm/trunk/engines/sci/engine/script.cpp
    scummvm/trunk/engines/sci/engine/vm.cpp
    scummvm/trunk/engines/sci/engine/vm.h
    scummvm/trunk/engines/sci/exereader.cpp
    scummvm/trunk/engines/sci/gfx/gfx_gui.cpp
    scummvm/trunk/engines/sci/gfx/gfx_res_options.cpp
    scummvm/trunk/engines/sci/gfx/gfx_res_options.h
    scummvm/trunk/engines/sci/gfx/gfx_resmgr.cpp
    scummvm/trunk/engines/sci/gfx/gfx_widgets.cpp
    scummvm/trunk/engines/sci/gfx/menubar.cpp
    scummvm/trunk/engines/sci/gfx/operations.cpp
    scummvm/trunk/engines/sci/module.mk
    scummvm/trunk/engines/sci/sci.h
    scummvm/trunk/engines/sci/scicore/resource.cpp
    scummvm/trunk/engines/sci/scicore/resource.h
    scummvm/trunk/engines/sci/scicore/versions.h
    scummvm/trunk/engines/sci/scicore/vocab_debug.cpp
    scummvm/trunk/engines/sci/sfx/softseq/adlib.cpp

Removed Paths:
-------------
    scummvm/trunk/engines/sci/scicore/versions.cpp

Modified: scummvm/trunk/engines/sci/detection.cpp
===================================================================
--- scummvm/trunk/engines/sci/detection.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/detection.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -105,7 +105,7 @@
 		{"resource.map", 0, resMapMd5, resMapSize}, \
 		{"resource.001", 0, resMd5, resSize}, \
 		{NULL, 0, NULL, 0}}, lang, Common::kPlatformPC, 0}, \
-		{}, \
+		0, \
 		SCI_VERSION_AUTODETECT, \
 		ver \
 	}
@@ -121,7 +121,7 @@
 		{"resource.map", 0, "f3d1be7752d30ba60614533d531e2e98", 474},
 		{"resource.001", 0, "6fd05926c2199af0af6f72f90d0d7260", 126895},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 453)
 	},
@@ -135,7 +135,7 @@
 		{"resource.002", 0, "d226d7d3b4f77c4a566913fc310487fc", 792380},
 		{"resource.003", 0, "d226d7d3b4f77c4a566913fc310487fc", 464348},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -149,7 +149,7 @@
 		{"resource.002", 0, "85e51acb5f9c539d66e3c8fe40e17da5", 826309},
 		{"resource.003", 0, "85e51acb5f9c539d66e3c8fe40e17da5", 493638},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -160,7 +160,7 @@
 		{"resource.000", 0, "9780f040d58182994e22d2e34fab85b0", 67367},
 		{"resource.001", 0, "2af49dbd8f2e1db4ab09f9310dc91259", 570553},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 5)
 	},
@@ -173,7 +173,7 @@
 		{"resource.001", 0, "d2f5a1be74ed963fa849a76892be5290", 794832},
 		{"resource.002", 0, "c0c29c51af66d65cb53f49e785a2d978", 1280907},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 510)
 	},
@@ -185,7 +185,7 @@
 		{"resource.000", 0, "27ec5fa09cd12a7fd16e86d96a2ed245", 1197694},
 		{"resource.001", 0, "735be4e58957180cfc807d5e18fdffcd", 1433302},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -196,7 +196,7 @@
 		{"resource.map", 0, "39485580d34a72997f3d5b3aba4d24f1", 426},
 		{"resource.001", 0, "11391434f41c834090d7a1e9488ce936", 129739},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 0, 294)
 	},
@@ -206,7 +206,7 @@
 		{"resource.map", 0, "8f656714a05b94423ac6eb10ee8797d0", 600},
 		{"resource.001", 0, "acde93e58fca4f7a2a5a220558a94aa8", 272629},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 172)
 	},
@@ -216,7 +216,7 @@
 		{"resource.map", 0, "44b8f45b841b9b5e17e939a35e443988", 600},
 		{"resource.001", 0, "acde93e58fca4f7a2a5a220558a94aa8", 335362},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 174)
 	},
@@ -226,7 +226,7 @@
 		{"resource.map", 0, "f1f8c8a8443f523422af70b4ec85b71c", 318},
 		{"resource.000", 0, "62fb9256f8e7e6e65a6875efdb7939ac", 203396},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 55)
 	},
@@ -242,7 +242,7 @@
 		{"resource.004", 0, "8613c45fc771d658e5a505b9a4a54f31", 713382},
 		{"resource.005", 0, "605b67a9ef199a9bb015745e7c004cf4", 478384},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -257,7 +257,7 @@
 		{"resource.003", 0, "d97a96f1ab91b41cf46a02cc89b0a04e", 624303},
 		{"resource.004", 0, "8613c45fc771d658e5a505b9a4a54f31", 670883},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -271,7 +271,7 @@
 		{"resource.003", 0, "dc7c5280e7acfaffe6ef2a6c963c5f94", 622118},
 		{"resource.004", 0, "64f342463f6f35ba71b3509ef696ae3f", 669188},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 668)
 	},
@@ -288,7 +288,7 @@
 		{"resource.005", 0, "c6e551bdc24f0acc193159038d4ca767", 605882},
 		{"resource.006", 0, "8f880a536908ab496bbc552f7f5c3738", 585255},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -298,7 +298,7 @@
 		{"resource.map", 0, "f4cd75c15be75e04cdca3acda2c0b0ea", 468},
 		{"resource.001", 0, "4930708722f34bfbaa4945fb08f55f61", 232523},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 668)
 	},
@@ -312,7 +312,7 @@
 		{"resource.003", 0, "8e1a3a8c588007404b532b8dfacc1460", 723712},
 		{"resource.004", 0, "8e1a3a8c588007404b532b8dfacc1460", 729143},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -328,7 +328,7 @@
 		{"resource.006", 0, "8e1a3a8c588007404b532b8dfacc1460", 332446},
 		{"resource.007", 0, "8e1a3a8c588007404b532b8dfacc1460", 358182},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -345,7 +345,7 @@
 		{"resource.005", 0, "1c3804e56b114028c5873a35c2f06d13", 653002},
 		{"resource.006", 0, "f9487732289a4f4966b4e34eea413325", 842817},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -361,7 +361,7 @@
 	      {"resource.005", 0, "d036df0872f2db19bca34601276be2d7", 1154950},
 	      {"resource.006", 0, "b367a6a59f29ee30dde1d88a5a41152d", 1042966},
 	      {NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-	      {},
+	      0,
 	      SCI_VERSION_AUTODETECT,
 	      SCI_VERSION(1, 000, 510)
 	},
@@ -377,7 +377,7 @@
 		{"resource.004", 0, "9cfce07e204a329e94fda8b5657621da", 1261462},
 		{"resource.005", 0, "21ebe6b39b57a73fc449f67f013765aa", 1284720},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -392,7 +392,7 @@
 		{"resource.004", 0, "9cfce07e204a329e94fda8b5657621da", 1260237},
 		{"resource.005", 0, "21ebe6b39b57a73fc449f67f013765aa", 1284609},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -402,7 +402,7 @@
 		{"resource.map", 0, "cbc5cb73341de1bff1b1e20a640af220", 588},
 		{"resource.001", 0, "f05a20cc07eee85da8e999d0ac0f596b", 869916},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 181)
 	},
@@ -418,7 +418,7 @@
 		{"resource.005", 0, "d036df0872f2db19bca34601276be2d7", 1176914},
 		{"resource.006", 0, "b367a6a59f29ee30dde1d88a5a41152d", 1123585},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -429,7 +429,7 @@
 		{"resource.map", 0, "c819e171359b7c95f4c13b846d5c034e", 873},
 		{"resource.000", 0, "baf9393a9bfa73098adb501e5bc5487b", 657518},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 69)	// this is just a guess
 	},
@@ -439,7 +439,7 @@
 		{"resource.map", 0, "a4b73d5d2b55bdb6e44345e99c8fbdd0", 4804},
 		{"resource.000", 0, "d908dbef56816ac6c60dd145fdeafb2b", 3536046},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 64)
 	},
@@ -452,7 +452,7 @@
 		{"resource.002", 0, "28fe9b4f0567e71feb198bc9f3a2c605", 1241816},
 		{"resource.003", 0, "f3146df0ad4297f5ce35aa8c4753bf6c", 586832},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 510)
 	},
@@ -465,7 +465,7 @@
 		{"resource.002", 0, "323b3b12f43d53f27d259beb225f0aa7", 1129316},
 		{"resource.003", 0, "83ac03e4bddb2c1ac2d36d2a587d0536", 1145616},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 510)
 	},
@@ -478,7 +478,7 @@
 		{"resource.002", 0, "02d7d0411f7903aacb3bc8b0f8ca8a9a", 1202581},
 		{"resource.003", 0, "84dd11b6825255671c703aee5ceff620", 1175835},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 510)
 	},
@@ -492,7 +492,7 @@
 		{"resource.002", 0, "2d21a1d2dcbffa551552e3e0725d2284", 1186033},
 		{"resource.003", 0, "84dd11b6825255671c703aee5ceff620", 1174993},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 510)
 	},
@@ -502,7 +502,7 @@
 		{"resource.map", 0, "607cfa0d8a03b7d348c06ee727e3d939", 1321},
 		{"resource.000", 0, "dd6f614c43c029f063e93cd243af90a4", 525992},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 55)
 	},
@@ -512,7 +512,7 @@
 		{"resource.map", 0, "28fb7b6abb9fc1cb8882d7c2e701b63f", 5658},
 		{"resource.000", 0, "cc1d17e5637528dbe4a812699e1cbfc6", 4208192},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 65)
 	},
@@ -522,7 +522,7 @@
 		{"resource.map", 0, "97aa9fcfe84c9993a64debd28c32393a", 1909},
 		{"resource.000", 0, "5ea8e7a3ea10cce6efd5c106dc62fd8c", 867724},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 69)
 	},
@@ -532,7 +532,7 @@
 		{"resource.map", 0, "d46b282f228a67ba13bd4b4009e95f8f", 6058},
 		{"resource.000", 0, "ee3c64ffff0ba9fb08bea2624631c598", 5490246},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 132)
 	},
@@ -544,7 +544,7 @@
 		{"resource.000", 0, "96b07e9b914dba1c8dc6c78a176326df", 5233230},
 		{"resource.msg", 0, "554f65315d851184f6e38211489fdd8f", -1},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 132)	// this is just a guess
 	},
@@ -556,7 +556,7 @@
 		{"resource.000", 0, "96b07e9b914dba1c8dc6c78a176326df", 5233230},
 		{"resource.msg", 0, "304b5a5781800affd2235152a5794fa8", -1},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 132)	// this is just a guess
 	},
@@ -571,7 +571,7 @@
 		{"resource.003", 0, "05acdc256c742e79c50b9fe7ec2cc898", 863310},
 		{"resource.msg", 0, "45b5bf74933ac3727e4cc844446dc052", 796156},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 132)
 	},
@@ -583,7 +583,7 @@
 		{"resource.000", 0, "96b07e9b914dba1c8dc6c78a176326df", 5233230},
 		{"resource.msg", 0, "45b5bf74933ac3727e4cc844446dc052", 796156},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 132)
 	},
@@ -593,7 +593,7 @@
 		{"resource.map", 0, "a62a7eae85dd1e6b07f39662b278437e", 1918},
 		{"resource.000", 0, "4962a3c4dd44e36e78ea4a7a374c2220", 957382},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 95)
 	},
@@ -603,7 +603,7 @@
 		{"resource.map", 0, "7ee6859ef74314f6d91938c3595348a9", 282},
 		{"resource.001", 0, "f1e680095424e31f7fae1255d36bacba", 40692},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 0, 506)
 	},
@@ -614,7 +614,7 @@
 		{"resource.map", 0, "372d059f75856afa6d73dd84cbb8913d", 10783},
 		{"resource.000", 0, "69b7516962510f780d38519cc15fcc7c", 13022630},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -624,7 +624,7 @@
 		{"resource.map", 0, "65e8c14092e4c9b3b3538b7602c8c5ec", 10783},
 		{"resource.000", 0, "69b7516962510f780d38519cc15fcc7c", 13022630},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -634,7 +634,7 @@
 		{"resource.map", 0, "ad6508b0296b25c07b1f58828dc33696", 10789},
 		{"resource.000", 0, "091cf08910780feabc56f8551b09cb36", 13077029},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -645,7 +645,7 @@
 		{"resource.map", 0, "372d059f75856afa6d73dd84cbb8913d", 10996},
 		{"resource.000", 0, "69b7516962510f780d38519cc15fcc7c", 12581736},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -655,7 +655,7 @@
 		{"resource.map", 0, "a7d3e55114c65647310373cb390815ba", 11392},
 		{"resource.000", 0, "091cf08910780feabc56f8551b09cb36", 13400497},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -666,7 +666,7 @@
 		{"resource.map", 0, "7cb6e9bba15b544ec7a635c45bde9953", 11404},
 		{"resource.000", 0, "091cf08910780feabc56f8551b09cb36", 13381599},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -676,7 +676,7 @@
 		{"resource.map", 0, "39645952ae0ed8072c7e838f31b75464", 2490},
 		{"resource.000", 0, "eb3ed7477ca4110813fe1fcf35928561", 1718450},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 92)
 	},
@@ -697,7 +697,7 @@
 		{"resmap.006", 0, "ce9359037277b7d7976da185c2fa0aad", 2977},
 		{"ressci.006", 0, "8e44e03890205a7be12f45aaba9644b4", 60659424},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -710,7 +710,7 @@
 		{"resource.002", 0, "e0dd44069a62a463fd124974b915f10d", 342309},
 		{"resource.003", 0, "e0dd44069a62a463fd124974b915f10d", 328912},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 530)
 	},
@@ -720,7 +720,7 @@
 		{"resource.map", 0, "1034a218943d12f1f36e753fa10c95b8", 4386},
 		{"resource.001", 0, "e0dd44069a62a463fd124974b915f10d", 518308},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 530)
 	},
@@ -732,7 +732,7 @@
 		{"resource.001", 0, "e0dd44069a62a463fd124974b915f10d", 218755},
 		{"resource.002", 0, "e0dd44069a62a463fd124974b915f10d", 439502},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 519) // FIXME: some have 0.000.530, others x.yyy.zzz
 	},
@@ -744,7 +744,7 @@
 		{"resource.001", 0, "8f2dd70abe01112eca464cda818b5eb6", 98138},
 		{"resource.002", 0, "8f2dd70abe01112eca464cda818b5eb6", 196631},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 572)
 	},
@@ -755,7 +755,7 @@
 		{"resource.map", 0, "62ed48d20c580e5a98f102f7cd93706a", 1356},
 		{"resource.001", 0, "8f2dd70abe01112eca464cda818b5eb6", 222704},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -768,7 +768,7 @@
 		{"resource.000", 0, "595b6039ea1356e7f96a52c58eedcf22", 355791},
 		{"resource.001", 0, "143df8aef214a2db34c2d48190742012", 632273},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -781,7 +781,7 @@
 		{"resource.000", 0, "6ef28cac094dcd97fdb461662ead6f92", 541845},
 		{"resource.001", 0, "0a98a268ee99b92c233a0d7187c1f0fa", 845795},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)  // this is just a guess
 	},
@@ -791,7 +791,7 @@
 		{"resource.map", 0, "662087cb383e52e3cc4ae7ecb10e20aa", 938},
 		{"resource.000", 0, "24c10844792c54d476d272213cbac300", 675252},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 200)	// this is just a guess
 	},
@@ -803,7 +803,7 @@
 		{"resource.001", 0, "bac3ec6cb3e3920984ab0f32becf5163", 313476},
 		{"resource.002", 0, "b86daa3ba2784d1502da881eedb80d9b", 719747},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 172)
 	},
@@ -818,7 +818,7 @@
 		{"resource.003", 0, "9ae2a13708d691cd42f9129173c4b39d", 763224},
 		{"resource.004", 0, "9ae2a13708d691cd42f9129173c4b39d", 820443},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_01,
 		SCI_VERSION(0, 001, 10)
 	},
@@ -831,7 +831,7 @@
 		{"resource.002", 0, "fed9e0072ffd511d248674e60dee2099", 714062},
 		{"resource.003", 0, "fed9e0072ffd511d248674e60dee2099", 717478},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 999)
 	},
@@ -846,7 +846,7 @@
 		{"resource.003", 0, "fd16c9c223f7dc5b65f06447615224ff", 683016},
 		{"resource.004", 0, "3fac034c7d130e055d05bc43a1f8d5f8", 549993},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -860,7 +860,7 @@
 		{"resource.003", 0, "77615c595388acf3d1df8e107bfb6b52", 707591},
 		{"resource.004", 0, "77615c595388acf3d1df8e107bfb6b52", 479562},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 502)
 	},
@@ -876,7 +876,7 @@
 		{"resource.006", 0, "851a62d00972dc4002f472cc0d84e71d", 333777},
 		{"resource.007", 0, "851a62d00972dc4002f472cc0d84e71d", 341038},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 274)
 	},
@@ -892,7 +892,7 @@
 		{"resource.006", 0, "0c8566848a76eea19a6d6220914030a7", 337288},
 		{"resource.007", 0, "0c8566848a76eea19a6d6220914030a7", 343882},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 253)
 	},
@@ -910,7 +910,7 @@
 		{"resource.006", 0, "26c0c25399b6715fec03fc3e12544fe3", 823048},
 		{"resource.007", 0, "b914b5901e786327213e779725d30dd1", 778772},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 60)
 	},
@@ -928,7 +928,7 @@
 		{"resource.006", 0, "56546b20db11a4836f900efa6d3a3e74", 672099},
 		{"resource.007", 0, "56546b20db11a4836f900efa6d3a3e74", 794194},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 60)
 	},
@@ -946,7 +946,7 @@
 		{"resource.006", 0, "11cb750f5f816445ad0f4b9f50a4f59a", 672527},
 		{"resource.007", 0, "11cb750f5f816445ad0f4b9f50a4f59a", 794259},
 		{NULL, 0, NULL, 0}}, Common::IT_ITA, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 60)
 	},
@@ -958,7 +958,7 @@
 		{"resource.000", 0, "449471bfd77be52f18a3773c7f7d843d", 571368},
 		{"resource.001", 0, "b45a581ff8751e052c7e364f58d3617f", 16800210},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 784)
 	},
@@ -975,7 +975,7 @@
 		{"resource.006", 0, "672ede1136e9e401658538e51bd5dc22", 1172619},
 		{"resource.007", 0, "2f48faf27666b58c276dda20f91f4a93", 1240456},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 60)
 	},
@@ -992,7 +992,7 @@
 		{"resource.006", 0, "d1a75fdc01840664d00366cff6919366", 1208972},
 		{"resource.007", 0, "c07494f0cce7c05210893938786a955b", 1337361},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 60)
 	},
@@ -1009,7 +1009,7 @@
 		{"resource.006", 0, "8eeabd92af71e766e323db2100879102", 1209325},
 		{"resource.007", 0, "dc10c107e0923b902326a040b9c166b9", 1337859},
 		{NULL, 0, NULL, 0}}, Common::IT_ITA, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 60)
 	},
@@ -1026,7 +1026,7 @@
 		{"resource.006", 0, "da82e4beb744731d0a151f1d4922fafa", 1170456},
 		{"resource.007", 0, "431def14ca29cdb5e6a5e84d3f38f679", 1240176},
 		{NULL, 0, NULL, 0}}, Common::PL_POL, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 60)
 	},
@@ -1038,7 +1038,7 @@
 		{"resource.000", 0, "535b1b920441ec73f42eaa4ccfd47b89", 264116},
 		{"resource.msg", 0, "54d1fdc936f98c81f9e4c19e04fb1510", 8260},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 55)
 	},
@@ -1049,7 +1049,7 @@
 		{"resource.000", 0, "f2b7f753992c56a0c7a08d6a5077c895", 7863324},
 		{"resource.msg", 0, "3cf5de44de36191f109d425b8450efc8", 258590},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 54)
 	},
@@ -1060,7 +1060,7 @@
 		{"resource.000", 0, "f2b7f753992c56a0c7a08d6a5077c895", 7863324},
 		{"resource.msg", 0, "756297b2155db9e43f621c6f6fb763c3", 282822},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 54)
 	},
@@ -1071,7 +1071,7 @@
 		{"resource.map", 0, "7a550ebfeae2575ca00d47703a6a774c", 9215},
 		{"resource.000", 0, "233394a5f33b475ae5975e7e9a420865", 8376352},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 69)
 	},
@@ -1083,7 +1083,7 @@
 		{"resource.000", 0, "4da3ad5868a775549a7cc4f72770a58e", 8537260},
 		{"resource.msg", 0, "41eed2d3893e1ca6c3695deba4e9d2e8", 267102},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 55)
 	},
@@ -1095,7 +1095,7 @@
 		{"resource.map", 0, "2be9ab94429c721af8e05c507e048a15", 18697},
 		{"resource.000", 0, "eb63ea3a2c2469dc2d777d351c626404", 203882535},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -1105,7 +1105,7 @@
 		{"resource.map", 0, "8676b0fbbd7362989a029fe72fea14c6", 18709},
 		{"resource.000", 0, "51c1ead1163e19a2de8f121c39df7a76", 200764100},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -1115,7 +1115,7 @@
 		{"resource.map", 0, "838b9ff132bd6962026fee832e8a7ddb", 18697},
 		{"resource.000", 0, "eb63ea3a2c2469dc2d777d351c626404", 206626576},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -1126,7 +1126,7 @@
 		{"resource.map", 0, "0b62693cbe87e3aaca3e8655a437f27f", 18709},
 		{"resource.000", 0, "51c1ead1163e19a2de8f121c39df7a76", 200764100},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -1136,7 +1136,7 @@
 		{"resource.map", 0, "b44f774108d63faa1d021101221c5a54", 1690},
 		{"resource.000", 0, "d9659d2cf0c269c6a9dc776707f5bea0", 2433827},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -1153,7 +1153,7 @@
 		{"resource.004", 0, "aa553977f7e5804081de293800d3bcce", 695067},
 		{"resource.005", 0, "bfd870d51dc97729f0914095f58e6957", 676881},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -1167,7 +1167,7 @@
 		{"resource.003", 0, "e45c888d9c7c04aec0a20e9f820b79ff", 667365},
 		{"resource.004", 0, "e45c888d9c7c04aec0a20e9f820b79ff", 683737},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAtariST, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -1180,7 +1180,7 @@
 		{"resource.003", 0, "e45c888d9c7c04aec0a20e9f820b79ff", 667468},
 		{"resource.004", 0, "e45c888d9c7c04aec0a20e9f820b79ff", 683807},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 631)
 	},
@@ -1197,7 +1197,7 @@
 		{"resource.006", 0, "e45c888d9c7c04aec0a20e9f820b79ff", 328390},
 		{"resource.007", 0, "e45c888d9c7c04aec0a20e9f820b79ff", 317687},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 631)	// FIXME: some versions are v. 0.000.685
 	},
@@ -1214,7 +1214,7 @@
 		{"resource.006", 0, "e45c888d9c7c04aec0a20e9f820b79ff", 328390},
 		{"resource.007", 0, "e45c888d9c7c04aec0a20e9f820b79ff", 317687},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 631)	// FIXME: some versions are v. 0.000.685
 	},
@@ -1225,7 +1225,7 @@
 		{"resource.map", 0, "24dffc5db1d88c7999f13e8767ed7346", 855},
 		{"resource.000", 0, "2b2b1b4f7584f9b38fd13f6ab95634d1", 781912},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 69) // this is just a guess
 	},
@@ -1235,7 +1235,7 @@
 		{"resource.map", 0, "610bfd9a852004222f0faaf5fc9e630a", 6489},
 		{"resource.000", 0, "57084910bc923bff5d6d9bc1b56e9604", 5035964},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 274)
 	},
@@ -1246,7 +1246,7 @@
 		{"resource.map", 0, "a70945e61ba7ac7bfea6b7bd72c6aec5", 7274},
 		{"resource.000", 0, "82578b8d5a7e09c4c58891ca49fae35b", 5598672},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 69)
 	},
@@ -1258,7 +1258,7 @@
 		{"resource.map", 0, "3b6dfbcda210bbc3f23fd1927113bf98", 6483},
 		{"resource.000", 0, "57084910bc923bff5d6d9bc1b56e9604", 5028766},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 274)
 	},
@@ -1271,7 +1271,7 @@
 		{"resource.000", 0, "57084910bc923bff5d6d9bc1b56e9604", 5028766},
 		{"resource.msg", 0, "71f1f0cd9f082da2e750c793a8ed9d84", 286141},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 274)
 	},
@@ -1285,7 +1285,7 @@
 		{"resource.002", 0, "24c958bc922b07f91e25e8c93aa01fcf", 491230},
 		{"resource.003", 0, "685cd6c1e05a695ab1e0db826337ee2a", 553279},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 510)	// FIXME: some versions are v. 0.000.577
 	},
@@ -1300,7 +1300,7 @@
 		{"resource.002", 0, "5790ac0505f7ca98d4567132b875eb1e", 681041},
 		{"resource.003", 0, "4a34c3367c2fe7eb380d741374da1989", 572251},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 784)
 	},
@@ -1313,7 +1313,7 @@
 		{"resource.001", 0, "ec20246209d7b19f38989261e5c8f5b8", 1111226},
 		{"resource.002", 0, "85d6935ef77e6b0e16bc307640a0d913", 1088312},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 577)
 	},
@@ -1325,7 +1325,7 @@
 		{"resource.001", 0, "d34cadb11e1aefbb497cf91bc1d3baa7", 1114688},
 		{"resource.002", 0, "85b030bb66d5342b0a068f1208c431a8", 1078443},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -1335,7 +1335,7 @@
 		{"resource.map", 0, "434e1f6c39d71647b34f0ee57b2bbd68", 444},
 		{"resource.001", 0, "0c0768215c562d9dace4a5ca53696cf3", 359913},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 84)
 	},
@@ -1350,7 +1350,7 @@
 		{"resource.002", 0, "3fe2a3aec0ed53c7d6db1845a67e3aa2", 1095908},
 		{"resource.003", 0, "ac175df0ea9a2cba57f0248651856d27", 376556},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -1364,7 +1364,7 @@
 		{"resource.003", 0, "a0d4a625311d307257da7fc43d00459d", 570356},
 		{"resource.004", 0, "a0d4a625311d307257da7fc43d00459d", 717844},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 572)
 	},
@@ -1374,7 +1374,7 @@
 		{"resource.map", 0, "03dba704bb77da55a91ad27b5a3cac09", 528},
 		{"resource.001", 0, "9f5520f0297206928df0b0b36493cd33", 127532},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 409) // FIXME: no version number in executable (x.yyy.zzz)
 	},
@@ -1389,7 +1389,7 @@
 		{"resource.005", 0, "4a24443a25e2b1492462a52809605dc2", 277732},
 		{"resource.006", 0, "4a24443a25e2b1492462a52809605dc2", 345683},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 409)
 	},
@@ -1404,7 +1404,7 @@
 		{"resource.005", 0, "96033f57accfca903750413fd09193c8", 274953},
 		{"resource.006", 0, "96033f57accfca903750413fd09193c8", 345818},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 343)
 	},
@@ -1420,7 +1420,7 @@
 		{"resource.004", 0, "f408e59cbee1457f042e5773b8c53951", 651634},
 		{"resource.005", 0, "433911eb764089d493aed1f958a5615a", 524259},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -1433,7 +1433,7 @@
 		{"resource.003", 0, "f18441027154292836b973c655fa3175", 506807},
 		{"resource.004", 0, "f18441027154292836b973c655fa3175", 513651},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 572)
 	},
@@ -1449,7 +1449,7 @@
 		{"resource.006", 0, "f18441027154292836b973c655fa3175", 282465},
 		{"resource.007", 0, "f18441027154292836b973c655fa3175", 257174},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 572)
 	},
@@ -1461,7 +1461,7 @@
 		{"resource.001", 0, "f773d79b93dfd4052ec8c1cc64c1e6ab", 76525},
 		{"resource.002", 0, "f773d79b93dfd4052ec8c1cc64c1e6ab", 268299},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 0, 530)
 	},
@@ -1476,7 +1476,7 @@
 		{"resource.003", 0, "3827a9b17b926e12dcc336860f50612a", 587036},
 		{"resource.004", 0, "3827a9b17b926e12dcc336860f50612a", 691932},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 572)
 	},
@@ -1490,7 +1490,7 @@
 		{"resource.003", 0, "65f1bdaa20f6d0470e9d969f22473873", 586921},
 		{"resource.004", 0, "65f1bdaa20f6d0470e9d969f22473873", 690826},
 		{NULL, 0, NULL, 0}}, Common::FR_FRA, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 572)
 	},
@@ -1507,7 +1507,7 @@
 		{"resource.005", 0, "f8b2d1137bb767e5d232056b99dd69eb", 623621},
 		{"resource.006", 0, "bafc64e3144f115dc58c6aee02de98fb", 715598},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 784)
 	},
@@ -1525,7 +1525,7 @@
 		{"resource.006", 0, "bafc64e3144f115dc58c6aee02de98fb", 754966},
 		{"resource.007", 0, "59eba83ad465b08d763b44f86afa86f6", 683135},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 784)
 	},
@@ -1535,7 +1535,7 @@
 		{"resource.map", 0, "efe8d3f45ce4f6bd9a6643e0ac8d2a97", 504},
 		{"resource.001", 0, "8bd8d9c0b5f455ee1269d63ce86c50dd", 531380},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 181)
 	},
@@ -1552,7 +1552,7 @@
 		{"resource.006", 0, "dda27ce00682aa76198dac124bbbe334", 1024810},
 		{"resource.007", 0, "ac443fae1285fb359bf2b2bc6a7301ae", 1030656},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -1569,7 +1569,7 @@
 		{"resource.006", 0, "dda27ce00682aa76198dac124bbbe334", 1021774},
 		{"resource.007", 0, "ac443fae1285fb359bf2b2bc6a7301ae", 993408},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)	// placed the English version here
 	},
@@ -1587,7 +1587,7 @@
 		{"resource.006", 0, "dda27ce00682aa76198dac124bbbe334", 946540},
 		{"resource.007", 0, "ac443fae1285fb359bf2b2bc6a7301ae", 958842},
 		{NULL, 0, NULL, 0}}, Common::FR_FRA, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -1605,7 +1605,7 @@
 		{"resource.006", 0, "dda27ce00682aa76198dac124bbbe334", 1015136},
 		{"resource.007", 0, "ac443fae1285fb359bf2b2bc6a7301ae", 987222},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -1616,7 +1616,7 @@
 		{"resource.map", 0, "a99776df795127f387cb35dae872d4e4", 5919},
 		{"resource.000", 0, "a8989a5a89e7d4f702b26b378c7a357a", 7001981},
 		{NULL, 0, NULL, 0}}, Common::IT_ITA, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -1627,7 +1627,7 @@
 		{"resource.map", 0, "bb8a39d9e2a77ba449a1e591109ad9a8", 6973},
 		{"resource.000", 0, "4462fe48c7452d98fddcec327a3e738d", 5789138},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_1_1,
 		SCI_VERSION(1, 001, 113)
 	},
@@ -1637,7 +1637,7 @@
 		{"resource.map", 0, "0b91234b7112782962cb480b7791b6e2", 7263},
 		{"resource.000", 0, "57d5fe8bb9e044158514476ea7678eb0", 5754790},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_1_1,
 		SCI_VERSION(1, 001, 115)
 	},
@@ -1648,7 +1648,7 @@
 		{"resource.map", 0, "0c0804434ea62278dd15032b1947426c", 8872},
 		{"resource.000", 0, "9a9f4870504444cda863dd14d077a680", 18520872},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 002)
 	},
@@ -1659,7 +1659,7 @@
 		{"resource.map", 0, "bafe85f32738854135991d4324ad147e", 7268},
 		{"resource.000", 0, "f6cbc6da7b90ea135883e0759848ca2c", 5773160},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 115)
 	},
@@ -1670,7 +1670,7 @@
 		{"resource.map", 0, "badfdf446ffed569a310d2c63a249421", 8896},
 		{"resource.000", 0, "bd944d2b06614a5b39f1586906f0ee88", 18534274},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 002)
 	},
@@ -1681,7 +1681,7 @@
 		{"resource.map", 0, "97797ea775baaf18a1907d357d3c0ea6", 7268},
 		{"resource.000", 0, "f6cbc6da7b90ea135883e0759848ca2c", 5776092},
 		{NULL, 0, NULL, 0}}, Common::FR_FRA, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 115)
 	},
@@ -1692,7 +1692,7 @@
 		{"resource.map", 0, "d184e9aa4f2d4b5670ddb3669db82cda", 8896},
 		{"resource.000", 0, "bd944d2b06614a5b39f1586906f0ee88", 18538987},
 		{NULL, 0, NULL, 0}}, Common::FR_FRA, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 002)
 	},
@@ -1704,7 +1704,7 @@
 		{"resource.map", 0, "633bf8f42170b6271019917c8009989b", 6943},
 		{"resource.000", 0, "7884a8db9253e29e6b37a2651fd90ba3", 5733116},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 113)
 	},
@@ -1715,7 +1715,7 @@
 		{"resource.map", 0, "194f1578f2624db813c9072359ad1639", 783},
 		{"resource.001", 0, "3733433b517ec3d14a3331d9ab3842ae", 344830},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 29)
 	},
@@ -1726,7 +1726,7 @@
 		{"resmap.000", 0, "eae93e1b1d1ccc58b4691c371281c95d", 8188},
 		{"ressci.000", 0, "89353723488219e25589165d73ed663e", 66965678},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(3, 000, 000)
 	},
@@ -1736,7 +1736,7 @@
 		{"resmap.000", 0, "c11e6bfcfc2f2d05da47e5a7df3e9b1a", 8188},
 		{"ressci.000", 0, "a8c6817bb94f332ff498a71c8b47f893", 66971724},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(3, 000, 000)
 	},
@@ -1746,7 +1746,7 @@
 		{"resmap.000", 0, "4407849fd52fe3efb0c30fba60cd5cd4", 8206},
 		{"ressci.000", 0, "dc37c3055fffbefb494ff22b145d377b", 66964472},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(3, 000, 000)
 	},
@@ -1757,7 +1757,7 @@
 		{"resmap.000", 0, "9852a97141f789413f29bf956052acdb", 8212},
 		{"ressci.000", 0, "440b9fed89590abb4e4386ed6f948ee2", 67140181},
 		{NULL, 0, NULL, 0}}, Common::IT_ITA, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 000)	// FIXME: add version here
 	},
@@ -1769,7 +1769,7 @@
 		{"resmap.000", 0, "8f3d603e1acc834a5d598b30cdfc93f3", 8188},
 		{"ressci.000", 0, "32792f9bc1bf3633a88b382bb3f6e40d", 67071418},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(3, 000, 000)
 	},
@@ -1779,7 +1779,7 @@
 		{"ressci.000", 0, "5cc6159688b2dc03790a67c90ccc67f9", 10195878},
 		{"resmap.000", 0, "6a2b2811eef82e87cde91cf1de845af8", 2695},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 002)
 	},
@@ -1790,7 +1790,7 @@
 		{"resource.map", 0, "543124606352bfa5e07696ddf2a669be", 64},
 		{"resource.000", 0, "5d7714416b612463d750fb9c5690c859", 28952},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -1803,7 +1803,7 @@
 		{"resmap.002", 0, "c68db5333f152fea6ca2dfc75cad8b34", 7573},
 		{"ressci.002", 0, "175468431a979b9f317c294ce3bc1430", 94628315},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(3, 0, 0)
 	},
@@ -1816,7 +1816,7 @@
 		{"resmap.002", 0, "e7dc85884a2417e2eff9de0c63dd65fa", 7630},
 		{"ressci.002", 0, "3c8d627c555b0e3e4f1d9955bc0f0df4", 94631127},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(3, 0, 0)
 	},
@@ -1832,7 +1832,7 @@
 		{"resource.003", 0, "b1288e0821ee358d1ffe877e5900c8ec", 1047565},
 		{"resource.004", 0, "f79daa70390d73746742ffcfc3dc4471", 937580},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_01,
 		SCI_VERSION(1, 000, 145)
 	},
@@ -1846,7 +1846,7 @@
 		{"resource.002", 0, "564f516d991032e781492592a4eaa275", 1414142},
 		{"resource.003", 0, "dd6cef0c592eadb7e6be9a25307c57a2", 1344719},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_01,
 		SCI_VERSION(1, 000, 145)
 	},
@@ -1858,7 +1858,7 @@
 		{"resource.001", 0, "fb552ae550ca1dac19ed8f6a3767612d", 262885},
 		{"resource.002", 0, "fb552ae550ca1dac19ed8f6a3767612d", 817191},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_01,
 		SCI_VERSION(0, 001, 10)
 	},
@@ -1869,7 +1869,7 @@
 		{"resource.map", 0, "52aae15e493cafd1da7e1c9b657a5bb9", 7026},
 		{"resource.000", 0, "b7ecd8ae9e254e80310b5a668b276e6e", 2948975},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 31)
 	},
@@ -1881,7 +1881,7 @@
 		{"resource.map", 0, "5159a1578c4306bfe070a3e4d8c2e1d3", 4741},
 		{"resource.000", 0, "1926925c95d82f0999590e93b02887c5", 15150768},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -1893,7 +1893,7 @@
 		{"resource.map", 0, "1c7f311b0a2c927b2fbe81ae341fb2f6", 5790},
 		{"resource.001", 0, "5a0ed1d745855148364de1b3be099bac", 4369438},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 0, 999) // This is just a guess
 	},
@@ -1903,7 +1903,7 @@
 		{"resource.map", 0, "5b457cbe5042f557e5b610148171f6c0", 1158},
 		{"resource.001", 0, "453ea81ef66a50cbe33ce06302afe47f", 229737},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 679)
 	},
@@ -1927,7 +1927,7 @@
 		{"resmap.007", 0, "afbd16ea77869a720afa1c5371de107d", 7972},
 		//{"ressci.007", 0, "3aae6559aa1df273bc542d5ac6330d75", 25859038},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -1946,7 +1946,7 @@
 		{"resmap.005", 0, "8bd5ceeedcbe16dfe55d1b90dcd4be84", 1942},
 		{"ressci.005", 0, "05f9fe2bee749659acb3cd2c90252fc5", 67905112},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(3, 000, 000)
 	},
@@ -1958,7 +1958,7 @@
 		{"resource.map", 0, "35efa814fb994b1cbdac9611e401da67", 5013},
 		{"resource.000", 0, "e0d5ddf34eda903a38f0837e2aa7145b", 6401433},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 29)
 	},
@@ -1971,7 +1971,7 @@
 		{"resource.002", 0, "499737c21a28ac026e11ab817100d610", 511099},
 		{"resource.003", 0, "e008f5d6e2a7c4d4a0da0173e4fa8f8b", 553970},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685) // exe seems packed, this is a guess
 	},
@@ -1986,7 +1986,7 @@
 		{"resource.005", 0, "77f02def3094af804fd2371db25b7100", 349899},
 		{"resource.006", 0, "77f02def3094af804fd2371db25b7100", 354991},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 395)
 	},
@@ -1999,7 +1999,7 @@
 		{"resource.002", 0, "77f02def3094af804fd2371db25b7100", 546000},
 		{"resource.003", 0, "77f02def3094af804fd2371db25b7100", 591851},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 490)
 	},
@@ -2011,7 +2011,7 @@
 		{"resource.002", 0, "77f02def3094af804fd2371db25b7100", 542897},
 		{"resource.003", 0, "77f02def3094af804fd2371db25b7100", 586857},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 395)
 	},
@@ -2026,7 +2026,7 @@
 		{"resource.003", 0, "630bfa65beb05f743552704ac2899dae", 759891},
 		{"resource.004", 0, "7b229fbdf30d670d0728cede3e984a7e", 838663},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 784)
 	},
@@ -2042,7 +2042,7 @@
 		{"resource.004", 0, "6258d5dd85898d8e218eb8113ebc9059", 722738},
 		{"resource.005", 0, "6258d5dd85898d8e218eb8113ebc9059", 704485},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 784)
 	},
@@ -2057,7 +2057,7 @@
 		{"resource.003", 0, "8791b9eef53edf77c2dac950142221d3", 1159791},
 		{"resource.004", 0, "1b91e891a3c60a941dac0eecdf83375b", 1143606},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -2069,7 +2069,7 @@
 		{"resource.000", 0, "277f97771f7a6d89677141f02da313d6", 65150},
 		{"resource.001", 0, "5c5a551b6c86cce2ee75becb90e0b586", 624411},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 510)
 	},
@@ -2084,7 +2084,7 @@
 		{"resource.003", 0, "4836f460f4cfc8de61e2df4c45775504", 1180956},
 		{"resource.004", 0, "0c3eb84b9755852d9e795e0d5c9373c7", 1171760},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -2095,7 +2095,7 @@
 		{"resource.map", 0, "be56f87a1c4a13062a30a362df860c2f", 1472},
 		{"resource.000", 0, "527d5684016e6816157cd15d9071b11b", 1121310},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 96)
 	},
@@ -2106,7 +2106,7 @@
 		{"resource.map", 0, "379dfe80ed6bd16c47e4b950c4722eac", 11374},
 		{"resource.000", 0, "fd316a09b628b7032248139003369022", 18841068},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 002)
 	},
@@ -2116,7 +2116,7 @@
 		{"resource.map", 0, "aed9643158ccf01b71f359db33137f82", 9895},
 		{"resource.000", 0, "da383857b3be1e4514daeba2524359e0", 15141432},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -2126,7 +2126,7 @@
 		{"resource.map", 0, "2393ee728ab930b2762cb5889f9b5aff", 9256},
 		{"resource.000", 0, "6ba98bd2e436739d87ecd2a9b99cabb4", 14730155},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -2137,7 +2137,7 @@
 		{"resource.map", 0, "8c96733ef94c21526792f7ca4e3f2120", 1648},
 		{"resource.000", 0, "d8892f1b8c56c8f7704325460f49b300", 3676175},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2154,7 +2154,7 @@
 		{"resmap.004", 0, "4228038906f041623e65789500b22285", 6835},
 		{"ressci.004", 0, "b7e619e6ecf62fe65d5116a3a422e5f0", 46223872},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2170,7 +2170,7 @@
 		{"resource.003", 0, "7ab2bf8e224b57f75e0cd6e4ba790761", 642203},
 		{"resource.004", 0, "7ab2bf8e224b57f75e0cd6e4ba790761", 641688},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 566)
 	},
@@ -2188,7 +2188,7 @@
 		{"resource.006", 0, "69366c2a2f99917199fe1b60a4fee19d", 267852},
 		{"resource.007", 0, "7ab2bf8e224b57f75e0cd6e4ba790761", 272747},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 566)
 	},
@@ -2204,7 +2204,7 @@
 		{"resource.004", 0, "16cd4414c37ae3bb6d6da33dce8e25e8", 689124},
 		{"resource.005", 0, "5f3386ef2f2b1254e4a066f5d9027324", 609529},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -2218,7 +2218,7 @@
 		{"resource.003", 0, "951299a82a8134ed12c5c18118d45c2f", 640483},
 		{"resource.004", 0, "951299a82a8134ed12c5c18118d45c2f", 644443},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 629)
 	},
@@ -2228,7 +2228,7 @@
 		{"resource.map", 0, "a731fb6c9c0b282443f7027bc8694d4c", 8469},
 		{"resource.000", 0, "ecace1a2771846b1a8aa1afdd44111a0", 6570147},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 411)
 	},
@@ -2238,7 +2238,7 @@
 		{"resource.map", 0, "ac0257051c95a59c0cdc0be24d9b11fa", 729},
 		{"resource.000", 0, "ec6f5cf369054dd3e5392995e9975b9e", 768218},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 29)
 	},
@@ -2256,7 +2256,7 @@
 		{"resource.006", 0, "ccf5dba33e5cab6d5872838c0f8db44c", 500039},
 		{"resource.007", 0, "4c9fc1587545879295cb9627f56a2cb8", 575056},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 001, 10)
 	},
@@ -2270,7 +2270,7 @@
 		{"resource.003", 0, "b192607c42f6960ecdf2ad2e4f90e9bc", 972804},
 		{"resource.004", 0, "cd2de58e27665d5853530de93fae7cd6", 983617},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 72)
 	},
@@ -2287,7 +2287,7 @@
 		{"resource.006", 0, "b1944bd664ddbd2859cdaa0c4a0d6281", 507489},
 		{"resource.007", 0, "cd2de58e27665d5853530de93fae7cd6", 490794},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 0, 72)
 	},
@@ -2298,7 +2298,7 @@
 		{"resource.map", 0, "fd71de9b588a45f085317caacf050e91", 687},
 		{"resource.000", 0, "b6c69bf6c18bf177492249fe81fc6a6d", 648702},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 21)
 	},
@@ -2308,7 +2308,7 @@
 		{"resource.map", 0, "19e2bf9b693932b5e2bb59b9f9ab86c9", 5958},
 		{"resource.000", 0, "6178ad2e83e58e4671ca03315f7a6498", 5868000},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 50)
 	},
@@ -2319,7 +2319,7 @@
 		{"resource.map", 0, "19e2bf9b693932b5e2bb59b9f9ab86c9", 5958},
 		{"resource.000", 0, "6178ad2e83e58e4671ca03315f7a6498", 5868042},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 83)
 	},
@@ -2331,7 +2331,7 @@
 		{"resource.000", 0, "ba7ac86155e4c531e46cd73c86daa80a", 5884098},
 		{"resource.msg", 0, "a63974730d294dec0bea10057c36e506", 256014},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 83)
 	},
@@ -2342,7 +2342,7 @@
 		{"resource.map", 0, "685bdb1ed47bbbb0e5e25db392da83ce", 9301},
 		{"resource.000", 0, "f64fd6aa3977939a86ff30783dd677e1", 11004993},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -2352,7 +2352,7 @@
 		{"resource.map", 0, "9e0abba8746f40565bc7eb5720522ecd", 9301},
 		{"resource.000", 0, "57f22cdc54eeb35fce1f26b31b5c3ee1", 11076197},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -2362,7 +2362,7 @@
 		{"resource.map", 0, "1ba7c7ae1efb315326d45cb931569b1b", 922},
 		{"resource.000", 0, "41ba03f0b188b029132daa3ece0d3e14", 623154},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 69)	// FIXME: no version number in executable
 								// so 1.001.69 is a guess
@@ -2374,7 +2374,7 @@
 		{"resource.map", 0, "aba367f2102e81782d961b14fbe3d630", 10246},
 		{"resource.000", 0, "263dce4aa34c49d3ad29bec889007b1c", 11571394},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2388,7 +2388,7 @@
 		{"resource.map", 0, "aba367f2102e81782d961b14fbe3d630", 10246},
 		{"resource.000", 0, "263dce4aa34c49d3ad29bec889007b1c", 11571394},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2400,7 +2400,7 @@
 		{"resource.map", 0, "9e0abba8746f40565bc7eb5720522ecd", 9301},
 		{"resource.000", 0, "57f22cdc54eeb35fce1f26b31b5c3ee1", 11076197},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 000, 000)
 	},
@@ -2416,7 +2416,7 @@
 		{"resmap.003", 0, "31ef4c0621711585d031f0ae81707251", 1636},
 		{"ressci.003", 0, "2a68edd064e5e4937b5e9c74b38f2082", 6860492},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(3, 000, 000)
 	},
@@ -2426,7 +2426,7 @@
 		{"ressci.001", 0, "2a68edd064e5e4937b5e9c74b38f2082", 70611091},
 		{"resmap.001", 0, "70ba2ff04a2b7fb2c52420ba7fbd47c2", 8338},
 		{NULL, 0, NULL, 0}}, Common::IT_ITA, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(3, 000, 000)
 	},
@@ -2437,7 +2437,7 @@
 		{"resmap.000", 0, "f2ead37749ed8f6535a2445a7d05a0cc", 46525},
 		{"ressci.000", 0, "4294c6d7510935f2e0a52e302073c951", 262654836},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2447,7 +2447,7 @@
 		{"resmap.000", 0, "f483d0a1f78334c18052e92785c3086e", 46537},
 		{"ressci.000", 0, "6751b144671e2deed919eb9d284b07eb", 262390692},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2458,7 +2458,7 @@
 		{"resmap.000", 0, "d9e0bc5eddefcbe47f528760085d8927", 1186},
 		{"ressci.000", 0, "3a93c6340b54e07e65d0e5583354d186", 10505469},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformWindows, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 000)	// FIXME: add version here
 	},
@@ -2475,7 +2475,7 @@
 		{"resource.004", 0, "b25a1539c71701f7715f738c5037e9a6", 775515},
 		{"resource.005", 0, "640ffe1a9acde392cc33cc1b1a528328", 806324},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510) // TODO: best bet, exe seems packed
 	},
@@ -2490,7 +2490,7 @@
 		{"resource.003", 0, "c47600e50c6fc591957ae0c5020ee7b8", 1213262},
 		{"resource.004", 0, "e19ea4ad131472f9238590f2e1d40289", 1203051},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -2500,7 +2500,7 @@
 		{"resource.map", 0, "5af709ac5e0e923e0b8174f49978c30e", 636},
 		{"resource.001", 0, "fd99ea43f57576ded7c86036996346cf", 507642},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 181)
 	},
@@ -2516,7 +2516,7 @@
 		{"resource.004", 0, "9b78228ad4f9f335fedf74f1812dcfca", 513325},
 		{"resource.005", 0, "7d4ebcb745c0bf8fc42e4013f52ecd49", 1101812},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 510)
 	},
@@ -2529,7 +2529,7 @@
 		{"resource.003", 0, "ceeda7202b96e5c85ecaa88a40a540fc", 746496},
 		{"resource.004", 0, "ceeda7202b96e5c85ecaa88a40a540fc", 761984},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685) // TODO: best bet, exe seems packed
 	},
@@ -2544,7 +2544,7 @@
 		{"resource.004", 0, "6d8f34090503ce937e7dbef6cb6cdb6a", 545053},
 		{"resource.005", 0, "6d8f34090503ce937e7dbef6cb6cdb6a", 687507},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 784)
 	},
@@ -2554,7 +2554,7 @@
 		{"resource.map", 0, "ec66ac2b1ce58b2575ba00b65058de1a", 612},
 		{"resource.001", 0, "ceeda7202b96e5c85ecaa88a40a540fc", 180245},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 453)
 	},
@@ -2566,7 +2566,7 @@
 		{"resource.002", 0, "ceeda7202b96e5c85ecaa88a40a540fc", 720244},
 		{"resource.003", 0, "ceeda7202b96e5c85ecaa88a40a540fc", 688367},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 453)
 	},
@@ -2579,7 +2579,7 @@
 		{"resource.002", 0, "8b55c4875298f45ea5696a5ee8f6a7fe", 715777},
 		{"resource.003", 0, "8b55c4875298f45ea5696a5ee8f6a7fe", 703370},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 685)
 	},
@@ -2596,7 +2596,7 @@
 		{"resource.006", 0, "9107c2aa5398e28b5c5406df13491f85", 320643},
 		{"resource.007", 0, "9107c2aa5398e28b5c5406df13491f85", 344287},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 453)	// FIXME: some versions are v. 0.000.685/0.000.999
 	},
@@ -2610,7 +2610,7 @@
 		{"resource.002", 0, "9107c2aa5398e28b5c5406df13491f85", 596768},
 		{"resource.003", 0, "9107c2aa5398e28b5c5406df13491f85", 693573},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 001, 114)
 	},
@@ -2627,7 +2627,7 @@
 		{"resource.005", 0, "3540d1cc84d674cf4b2c898b88a3b563", 790296},
 		{"resource.006", 0, "ade814bc4d56244c156d9e9bcfebbc11", 664085},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 784)
 	},
@@ -2643,7 +2643,7 @@
 		{"resource.005", 0, "10ee1709e6559c724676d058199b75b5", 818745},
 		{"resource.006", 0, "67fb188b191d88efe8414af6ea297b93", 672675},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformAmiga, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 744) // TODO: best bet, exe seems packed
 	},
@@ -2654,7 +2654,7 @@
 		{"resource.map", 0, "ed90a8e3ccc53af6633ff6ab58392bae", 7054},
 		{"resource.000", 0, "63247e3901ab8963d4eece73747832e0", 5157378},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 001, 64)
 	},
@@ -2665,7 +2665,7 @@
 		{"resource.map", 0, "a18088c8aceb06025dbc945f29e02935", 5124},
 		{"resource.000", 0, "e1f46832cd2458796028e054a0466031", 5502009},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 200)
 	},
@@ -2676,7 +2676,7 @@
 		{"resource.map", 0, "71ccf4f82ac4efb588731acfb7bf2603", 5646},
 		{"resource.000", 0, "e1f46832cd2458796028e054a0466031", 933928},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 200)
 	},
@@ -2692,7 +2692,7 @@
 		{"resource.004", 0, "ff9c87da3bc53473fdee8b9d3edbc93c", 1200631},
 		{"resource.005", 0, "e33019ac19f755ae33fbf49b4fc9066c", 1053294},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 200)
 	},
@@ -2708,7 +2708,7 @@
 		{"resource.005", 0, "47ee647b5b12232d27e63cc627c25899", 1156765},
 		{"resource.006", 0, "dfb023e4e2a1e7a00fa18f9ede72a91b", 924059},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 200)
 	},
@@ -2723,7 +2723,7 @@
 		{"resource.004", 0, "4277c61bed40a50dadc4b5a344520af2", 1251000},
 		{"resource.005", 0, "5f885abd335978e2fd4e5f886d7676c8", 1102880},
 		{NULL, 0, NULL, 0}}, Common::IT_ITA, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 200)
 	},
@@ -2739,7 +2739,7 @@
 		{"resource.004", 0, "776fba81c110d1908776232cbe190e20", 1253752},
 		{"resource.005", 0, "55fae26c2a92f16ef72c1e216e827c0f", 1098328},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 200)
 	},
@@ -2753,7 +2753,7 @@
 		{"resource.002", 0, "74c62fa2146ff3b3b2ea2b3fb95b9af9", 1140801},
 		{"resource.003", 0, "42a307941edeb1a3be31daeb2e4be90b", 1088408},
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 200)
 	},
@@ -2769,7 +2769,7 @@
 		{"resource.004", 0, "c06350184a490c10eb4585fff0aa3192", 1254368},
 		{"resource.005", 0, "b8d6efbd3235329bfe844c794097b2c9", 1098717},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 000, 030)
 	},
@@ -2781,7 +2781,7 @@
 		{"resource.000", 0, "4147edc5045e6d62998018b5614c58ec", 5496486},
 		{"resource.msg", 0, "bb8ad78793c26bdb3f77498b1d6515a9", 125988},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 68)
 	},
@@ -2791,7 +2791,7 @@
 		{"resource.map", 0, "8bde0a9adb9a3e9aaa861826874c9834", 6473},
 		{"resource.000", 0, "f4a48705764544d7cc64a7bb22a610df", 6025184},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 67)
 	},
@@ -2802,7 +2802,7 @@
 		{"resource.000", 0, "4147edc5045e6d62998018b5614c58ec", 5496486},
 		{"resource.msg", 0, "7c71cfc36153cfe07b450423a51f7e68", 146282},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 68)
 	},
@@ -2813,7 +2813,7 @@
 		{"resource.000", 0, "5040026519f37199f3616fb1d4704dff", 6047170},
 		{"resource.map", 0, "5b09168baa2f6e2e22787429b2d72f54", 6492},
 		{NULL, 0, NULL, 0}}, Common::IT_ITA, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(0, 000, 000)	// FIXME: add version here
 	},
@@ -2826,7 +2826,7 @@
 		{"resource.map", 0, "6dddfa3a8f3a3a513ec9dfdfae955005", 10528},
 		{"resource.000", 0, "c4259ab7355aead07773397b1052827d", 41150806},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 002)
 	},
@@ -2836,7 +2836,7 @@
 		{"resource.map", 0, "e0615d6e4e10e37ae42e6a2a95aaf145", 10528},
 		{"resource.000", 0, "c4259ab7355aead07773397b1052827d", 41150806},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 002)
 	},
@@ -2846,7 +2846,7 @@
 		{"resource.map", 0, "368f07b07433db3f819fa3fa0e5efee5", 2572},
 		{"resource.000", 0, "ab12724e078dea34b624e0d2a38dcd7c", 2272050},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 002)
 	},
@@ -2856,7 +2856,7 @@
 		{"resource.map", 0, "664d797415484f85c90b1b45aedc7686", 10534},
 		{"resource.000", 0, "ba87ba91e5bdabb4169dd0df75777722", 40933685},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 002)
 	},
@@ -2868,7 +2868,7 @@
 		{"resource.map", 0, "2388efef8430b041b0f3b00b9050e4a2", 3281},
 		{"resource.000", 0, "b3acd9b9dd7fe53c4ee133ac9a1acfab", 2103560},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 53)
 	},
@@ -2879,7 +2879,7 @@
 		{"resource.map", 0, "3c07da06bdd1689f9d07af78fb94d0ec", 3101},
 		{"resource.000", 0, "ecc686e0034fb4d41de077ac7167b3cf", 1947866},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 53)
 	},
@@ -2889,7 +2889,7 @@
 		{"resource.map", 0, "a8e5ca8ed1996974afa59f4c45e06195", 986},
 		{"resource.000", 0, "b3acd9b9dd7fe53c4ee133ac9a1acfab", 586560},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformPC, ADGF_DEMO},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(1, 1, 53)
 	},
@@ -2900,7 +2900,7 @@
 		{"resmap.000", 0, "bb3b0b22ff08df54fbe2d06263409be6", 9799},
 		{"ressci.000", 0, "693a259d346c9360f4a0c11fdaae430a", 55973887},
 		{NULL, 0, NULL, 0}}, Common::EN_ANY, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2912,7 +2912,7 @@
 		{"ressci.000", 0, "693a259d346c9360f4a0c11fdaae430a", 55973887},
 		// TODO: depend on one of the patches?
 		{NULL, 0, NULL, 0}}, Common::ES_ESP, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2922,7 +2922,7 @@
 		{"resmap.000", 0, "bb3b0b22ff08df54fbe2d06263409be6", 9799},
 		{"ressci.000", 0, "693a259d346c9360f4a0c11fdaae430a", 55973887},
 		{NULL, 0, NULL, 0}}, Common::FR_FRA, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2932,7 +2932,7 @@
 		{"resmap.000", 0, "bb3b0b22ff08df54fbe2d06263409be6", 9799},
 		{"ressci.000", 0, "693a259d346c9360f4a0c11fdaae430a", 55973887},
 		{NULL, 0, NULL, 0}}, Common::DE_DEU, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2942,7 +2942,7 @@
 		{"resmap.000", 0, "bb3b0b22ff08df54fbe2d06263409be6", 9799},
 		{"ressci.000", 0, "693a259d346c9360f4a0c11fdaae430a", 55973887},
 		{NULL, 0, NULL, 0}}, Common::IT_ITA, Common::kPlatformWindows, 0},
-		{},
+		0,
 		SCI_VERSION_AUTODETECT,
 		SCI_VERSION(2, 100, 2)
 	},
@@ -2974,7 +2974,7 @@
 	// FIXME: The vga demo does not have a resource.000/001 file.
 	//FANMADE_V("SCI VGA Demo", "00b1abd87bad356b90fcdfcb6132c26f", 8, "", 0, SCI_VERSION(1, 0, 577)),
 
-	{AD_TABLE_END_MARKER, {}, SCI_VERSION_AUTODETECT, SCI_VERSION(0, 000, 000)}
+	{AD_TABLE_END_MARKER, 0, SCI_VERSION_AUTODETECT, SCI_VERSION(0, 000, 000)}
 };
 
 /**
@@ -2990,7 +2990,7 @@
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS
 	},
-	{},
+	0,
 	SCI_VERSION_AUTODETECT,
 	SCI_VERSION(0, 000, 000)
 };

Modified: scummvm/trunk/engines/sci/engine/game.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/game.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/engine/game.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -26,6 +26,7 @@
 #include "common/system.h"
 #include "common/file.h"
 
+#include "sci/sci.h"
 #include "sci/scicore/resource.h"
 #include "sci/engine/state.h"
 #include "sci/scicore/versions.h"
@@ -398,8 +399,6 @@
 		s->version_lock_flag = 1; // Lock version
 	}
 
-	script_detect_versions(s);
-
 	if (s->version >= SCI_VERSION(1, 001, 000))
 		result = create_class_table_sci11(s);
 	else
@@ -451,9 +450,6 @@
 	if (_init_vocabulary(s))
 		return 1;
 
-	if (s->selector_map.cantBeHere != -1)
-		version_require_later_than(s, SCI_VERSION_FTU_INVERSE_CANBEHERE);
-
 	s->restarting_flags = SCI_GAME_IS_NOT_RESTARTING;
 
 	s->bp_list = NULL; // No breakpoints defined

Modified: scummvm/trunk/engines/sci/engine/kevent.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/kevent.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/engine/kevent.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -23,6 +23,7 @@
  *
  */
 
+#include "sci/sci.h"
 #include "sci/engine/state.h"
 #include "sci/engine/kernel.h"
 #include "sci/gfx/gfx_widgets.h"

Modified: scummvm/trunk/engines/sci/engine/kgraphics.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/kgraphics.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/engine/kgraphics.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -25,6 +25,7 @@
 
 #include "common/system.h"
 
+#include "sci/sci.h"
 #include "sci/scicore/resource.h"
 #include "sci/engine/state.h"
 #include "sci/engine/kernel.h"

Modified: scummvm/trunk/engines/sci/engine/kmenu.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/kmenu.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/engine/kmenu.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -23,6 +23,7 @@
  *
  */
 
+#include "sci/sci.h"
 #include "sci/scicore/resource.h"
 #include "sci/engine/state.h"
 #include "sci/engine/kernel.h"

Modified: scummvm/trunk/engines/sci/engine/kpathing.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/kpathing.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/engine/kpathing.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -23,6 +23,7 @@
  *
  */
 
+#include "sci/sci.h"
 #include "sci/engine/state.h"
 #include "sci/engine/kernel.h"
 #include "sci/gfx/gfx_widgets.h"

Modified: scummvm/trunk/engines/sci/engine/savegame.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/savegame.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/engine/savegame.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -31,6 +31,7 @@
 #include <time.h>	// FIXME: For struct tm
 
 
+#include "sci/sci.h"
 #include "sci/gfx/operations.h"
 #include "sci/gfx/menubar.h"
 #include "sci/gfx/gfx_state_internal.h"	// required for GfxPort, GfxContainer

Modified: scummvm/trunk/engines/sci/engine/script.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/script.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/engine/script.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -23,6 +23,7 @@
  *
  */
 
+#include "sci/sci.h"
 #include "sci/scicore/resource.h"
 #include "sci/engine/state.h"
 #include "common/util.h"

Modified: scummvm/trunk/engines/sci/engine/vm.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/vm.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/engine/vm.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -1583,29 +1583,6 @@
 	return _lookup_selector_function(s, obj_location.segment, obj, selector_id, fptr);
 }
 
-// Detects SCI versions by their different script header
-void script_detect_versions(EngineState *s) {
-	int c;
-	Resource *script = {0};
-
-	if (s->resmgr->findResource(kResourceTypeHeap, 0, 0)) {
-		version_require_later_than(s, SCI_VERSION(1, 001, 000));
-		return;
-	}
-
-	for (c = 0; c < 1000; c++) {
-		if ((script = s->resmgr->findResource(kResourceTypeScript, c, 0))) {
-
-			int id = (int16)READ_LE_UINT16(script->data);
-
-			if (id > 15) {
-				version_require_earlier_than(s, SCI_VERSION_FTU_NEW_SCRIPT_HEADER);
-				return;
-			}
-		}
-	}
-}
-
 SegmentId script_get_segment(EngineState *s, int script_nr, int load) {
 	SegmentId segment;
 

Modified: scummvm/trunk/engines/sci/engine/vm.h
===================================================================
--- scummvm/trunk/engines/sci/engine/vm.h	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/engine/vm.h	2009-05-13 16:52:41 UTC (rev 40524)
@@ -982,13 +982,6 @@
 ** This function reads from and writes to s. It is called by script_run().
 */
 
-
-void script_detect_versions(EngineState *s);
-/* Detects SCI versions by their different script header
-** Parameters: (EngineState *) s: The state to operate on
-** Returns   : (void)
-*/
-
 reg_t kalloc(EngineState *s, const char *type, int space);
 /* Allocates "kernel" memory and returns a handle suitable to be passed on to SCI scripts
 ** Parameters: (EngineState *) s: Pointer to the EngineState to operate on

Modified: scummvm/trunk/engines/sci/exereader.cpp
===================================================================
--- scummvm/trunk/engines/sci/exereader.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/exereader.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -336,11 +336,20 @@
 	}
 
 	// Parse to a version number
-	if (!version_parse(mappedVersion.c_str(), version)) {
+	char *endptr[3];
+	const char *ver = mappedVersion.c_str();
+	int major = strtol(ver, &endptr[0], 10);
+	int minor = strtol(ver + 2, &endptr[1], 10);
+	int patchlevel = strtol(ver + 6, &endptr[2], 10);
+
+	if (endptr[0] != ver + 1 || endptr[1] != ver + 5 || *endptr[2] != '\0') {
+		warning("Failed to parse version string '%s'", ver);
 		return true;
-	} else {
-		return false;
 	}
+
+	*version = SCI_VERSION(major, minor, patchlevel);
+
+	return false;
 }
 
 } // End of namespace Sci

Modified: scummvm/trunk/engines/sci/gfx/gfx_gui.cpp
===================================================================
--- scummvm/trunk/engines/sci/gfx/gfx_gui.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/gfx/gfx_gui.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -23,6 +23,7 @@
  *
  */
 
+#include "sci/sci.h"
 #include "sci/engine/state.h"
 #include "sci/gfx/operations.h"
 #include "sci/gfx/gfx_widgets.h"

Modified: scummvm/trunk/engines/sci/gfx/gfx_res_options.cpp
===================================================================
--- scummvm/trunk/engines/sci/gfx/gfx_res_options.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/gfx/gfx_res_options.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -23,6 +23,7 @@
  *
  */
 
+#include "sci/sci.h"
 #include "sci/gfx/gfx_system.h"
 #include "sci/gfx/gfx_options.h"
 #include "sci/gfx/gfx_resmgr.h"

Modified: scummvm/trunk/engines/sci/gfx/gfx_res_options.h
===================================================================
--- scummvm/trunk/engines/sci/gfx/gfx_res_options.h	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/gfx/gfx_res_options.h	2009-05-13 16:52:41 UTC (rev 40524)
@@ -30,6 +30,7 @@
 
 #ifdef CUSTOM_GRAPHICS_OPTIONS
 
+#include "sci/sci.h"
 #include "sci/gfx/gfx_resource.h"
 #include "sci/gfx/gfx_resmgr.h"
 

Modified: scummvm/trunk/engines/sci/gfx/gfx_resmgr.cpp
===================================================================
--- scummvm/trunk/engines/sci/gfx/gfx_resmgr.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/gfx/gfx_resmgr.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -29,6 +29,7 @@
 // filenames, are misleading. This should be renamed to "Graphics manager"
 // or something like that.
 
+#include "sci/sci.h"
 #include "sci/gfx/gfx_resource.h"
 #include "sci/gfx/gfx_tools.h"
 #include "sci/gfx/gfx_driver.h"

Modified: scummvm/trunk/engines/sci/gfx/gfx_widgets.cpp
===================================================================
--- scummvm/trunk/engines/sci/gfx/gfx_widgets.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/gfx/gfx_widgets.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -23,6 +23,7 @@
  *
  */
 
+#include "sci/sci.h"
 #include "sci/gfx/gfx_gui.h"		// for kWindowAutoRestore
 #include "sci/gfx/gfx_widgets.h"
 #include "sci/gfx/gfx_state_internal.h"

Modified: scummvm/trunk/engines/sci/gfx/menubar.cpp
===================================================================
--- scummvm/trunk/engines/sci/gfx/menubar.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/gfx/menubar.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -28,6 +28,7 @@
 ** used for any actual actions on behalf of the interpreter.
 */
 
+#include "sci/sci.h"
 #include "sci/engine/state.h"
 #include "sci/gfx/menubar.h"
 #include "sci/engine/kernel.h"

Modified: scummvm/trunk/engines/sci/gfx/operations.cpp
===================================================================
--- scummvm/trunk/engines/sci/gfx/operations.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/gfx/operations.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -25,9 +25,9 @@
 
 // Graphical operations, called from the widget state manager
 
+#include "sci/sci.h"
 #include "sci/gfx/operations.h"
 #include "sci/gfx/font.h"
-#include "sci/sci.h"	// for g_engine, evil hack
 #include "sci/console.h"
 
 #include "common/system.h"

Modified: scummvm/trunk/engines/sci/module.mk
===================================================================
--- scummvm/trunk/engines/sci/module.mk	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/module.mk	2009-05-13 16:52:41 UTC (rev 40524)
@@ -55,7 +55,6 @@
 	scicore/decompressor.o \
 	scicore/resource.o \
 	scicore/sciconsole.o \
-	scicore/versions.o \
 	scicore/vocabulary.o \
 	scicore/vocab_debug.o \
 	sfx/adlib_sbi.o \

Modified: scummvm/trunk/engines/sci/sci.h
===================================================================
--- scummvm/trunk/engines/sci/scicore/resource.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/scicore/resource.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -28,6 +28,7 @@
 #include "common/util.h"
 #include "common/debug.h"
 
+#include "sci/sci.h"
 #include "sci/engine/state.h"
 #include "sci/engine/kernel.h"
 #include "sci/tools.h"

Modified: scummvm/trunk/engines/sci/scicore/resource.h
===================================================================
--- scummvm/trunk/engines/sci/scicore/resource.h	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/scicore/resource.h	2009-05-13 16:52:41 UTC (rev 40524)
@@ -71,18 +71,6 @@
 #define SCI_ERROR_CRITICAL SCI_ERROR_NO_RESOURCE_FILES_FOUND
 /* the first critical error number */
 
-/*** SCI VERSION NUMBERS ***/
-#define SCI_VERSION_AUTODETECT 0
-#define SCI_VERSION_0 1
-#define SCI_VERSION_01 2
-#define SCI_VERSION_01_VGA 3
-#define SCI_VERSION_01_VGA_ODD 4
-#define SCI_VERSION_1_EARLY 5
-#define SCI_VERSION_1_LATE 6
-#define SCI_VERSION_1_1 7
-#ifdef ENABLE_SCI32
-#define SCI_VERSION_32 8
-#endif
 #define SCI_VERSION_LAST SCI_VERSION_1_LATE /* The last supported SCI version */
 
 #define SCI_VERSION_1 SCI_VERSION_1_EARLY

Deleted: scummvm/trunk/engines/sci/scicore/versions.cpp
===================================================================
--- scummvm/trunk/engines/sci/scicore/versions.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/scicore/versions.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -1,90 +0,0 @@
-/* ScummVM - Graphic Adventure Engine
- *
- * ScummVM is the legal property of its developers, whose names
- * are too numerous to list here. Please refer to the COPYRIGHT
- * file distributed with this source distribution.
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL$
- * $Id$
- *
- */
-
-#define NEED_SCI_VERSIONS
-
-#include "common/system.h"
-#include "common/config-manager.h"
-
-#include "sci/scicore/versions.h"
-#include "sci/engine/state.h"
-#include "sci/tools.h"
-
-namespace Sci {
-
-void version_require_earlier_than(EngineState *s, sci_version_t version) {
-	if (s->version_lock_flag)
-		return;
-
-	if (version <= s->min_version) {
-		sciprintf("Version autodetect conflict: Less than %d.%03d.%03d was requested, but %d.%03d.%03d is the current minimum\n",
-		          SCI_VERSION_MAJOR(version), SCI_VERSION_MINOR(version), SCI_VERSION_PATCHLEVEL(version),
-		          SCI_VERSION_MAJOR(s->min_version), SCI_VERSION_MINOR(s->min_version),
-		          SCI_VERSION_PATCHLEVEL(s->min_version));
-		return;
-	} else if (version < s->max_version) {
-		s->max_version = version - 1;
-		if (s->max_version < s->version)
-			s->version = s->max_version;
-	}
-}
-
-void version_require_later_than(EngineState *s, sci_version_t version) {
-	if (s->version_lock_flag)
-		return;
-
-	if (version > s->max_version) {
-		sciprintf("Version autodetect conflict: More than %d.%03d.%03d was requested, but less than"
-		          "%d.%03d.%03d is required ATM\n",
-		          SCI_VERSION_MAJOR(version), SCI_VERSION_MINOR(version), SCI_VERSION_PATCHLEVEL(version),
-		          SCI_VERSION_MAJOR(s->max_version), SCI_VERSION_MINOR(s->max_version),
-		          SCI_VERSION_PATCHLEVEL(s->max_version));
-		return;
-	} else if (version > s->min_version) {
-		s->min_version = version;
-		if (s->min_version > s->version)
-			s->version = s->min_version;
-	}
-}
-
-int version_parse(const char *vn, sci_version_t *result) {
-	char *endptr[3];
-	int major = strtol(vn, &endptr[0], 10);
-	int minor = strtol(vn + 2, &endptr[1], 10);
-	int patchlevel = strtol(vn + 6, &endptr[2], 10);
-
-	if (endptr[0] != vn + 1 || endptr[1] != vn + 5 || *endptr[2] != '\0') {
-		warning("Failed to parse version string '%s'", vn);
-		return 1;
-	}
-
-	*result = SCI_VERSION(major, minor, patchlevel);
-
-	return 0;
-}
-
-#undef VERSION_DETECT_BUF_SIZE
-
-} // End of namespace Sci

Modified: scummvm/trunk/engines/sci/scicore/versions.h
===================================================================
--- scummvm/trunk/engines/sci/scicore/versions.h	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/scicore/versions.h	2009-05-13 16:52:41 UTC (rev 40524)
@@ -107,25 +107,6 @@
 
 struct EngineState;
 
-void version_require_earlier_than(EngineState *s, sci_version_t version);
-/* Function used in autodetection
-** Parameters: (EngineState *) s: EngineState containing the version
-**             (sci_version_t) version: The version that we're earlier than
-*/
-
-void version_require_later_than(EngineState *s, sci_version_t version);
-/* Function used in autodetection (read this function "version_require_later_than_or_equal_to")
-** Parameters: (EngineState *) s: EngineState containing the version
-**             (sci_version_t) version: The version that we're later than
-*/
-
-int version_parse(const char *vn, sci_version_t *result);
-/* Parse a string containing an SCI version number
-** Parameters: (char *) vn: The string to parse
-** Returns   : (int) 0 on success, 1 on failure
-**             (sci_version_t) *result: The resulting version number on success
-*/
-
 } // End of namespace Sci
 
 #endif // SCI_SCICORE_VERSIONS_H

Modified: scummvm/trunk/engines/sci/scicore/vocab_debug.cpp
===================================================================
--- scummvm/trunk/engines/sci/scicore/vocab_debug.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/scicore/vocab_debug.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -23,7 +23,7 @@
  *
  */
 
-
+#include "sci/sci.h"
 #include "sci/engine/state.h"
 #include "sci/scicore/resource.h"
 

Modified: scummvm/trunk/engines/sci/sfx/softseq/adlib.cpp
===================================================================
--- scummvm/trunk/engines/sci/sfx/softseq/adlib.cpp	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/sfx/softseq/adlib.cpp	2009-05-13 16:52:41 UTC (rev 40524)
@@ -23,6 +23,7 @@
  *
  */
 
+#include "sci/sci.h"
 #include "sci/tools.h"
 #include "sci/sfx/iterator.h"
 


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list
--- scummvm/trunk/engines/sci/sci.h	2009-05-13 16:22:26 UTC (rev 40523)
+++ scummvm/trunk/engines/sci/sci.h	2009-05-13 16:52:41 UTC (rev 40524)
@@ -57,71 +57,62 @@
 	kDebugLevelDclInflate = 1 << 17
 };
 
-struct GameFlags {
-	//int gameType;
-	//int gameId;
-	//uint32 features;
-	// SCI Version
-	// Resource Map Version
-	// etc...
-};
-
 struct SciGameDescription {
 	ADGameDescription desc;
-	GameFlags flags;
+	uint32 flags;
 	int res_version;
 	int version;
 };
 
+enum SciGameVersions {
+	SCI_VERSION_AUTODETECT = 0,
+	SCI_VERSION_0 = 1,
+	SCI_VERSION_01 = 2,
+	SCI_VERSION_01_VGA = 3,
+	SCI_VERSION_01_VGA_ODD = 4,
+	SCI_VERSION_1_EARLY = 5,
+	SCI_VERSION_1_LATE = 6,
+	SCI_VERSION_1_1 = 7,
+	SCI_VERSION_32 = 8
+};
+
 enum SciGameFlags {
 	/*
-	** SCI version flags
-	*/
-	GF_SCI0				= (1 << 0),
-	/*
-	** kDoSound() is different in this version than its SCI0 counterpart
-	*/
-	GF_SCI01			= (1 << 1),
-	GF_SCI1				= (1 << 2),
-	GF_SCI11			= (1 << 3),
-	GF_SCI32			= (1 << 4),
-
-	/*
 	** SCI0 flags
 	*/
 
-	/* First version known not to do this: 0.000.395
+	/* Applies to all versions before 0.000.395
 	** Old SCI versions used two word header for script blocks (first word equal
 	** to 0x82, meaning of the second one unknown). New SCI versions used one
 	** word header.
 	*/
-	GF_OLDSCRIPTHEADER	= (1 << 5),
+	GF_OLDSCRIPTHEADER	= (1 << 0),
 
-	/* First version known not to do this: 0.000.395
+	/* Applies to all versions before 0.000.395
 	** Earlier versions assign 120 degrees to left & right , and 60 to up and down.
 	** Later versions use an even 90 degree distribution.
 	*/
-	GF_OLDANGLES		= (1 << 6),
+	GF_OLDANGLES		= (1 << 1),
 
 	/* First version known not to do this: 0.000.490 (PQ2-new)
 	** When a new song is initialized, we store its state and
     ** resume it when the new one finishes.  Older versions completely
     ** clobbered the old songs.
 	*/
-	GF_OLDRESUMESONG	= (1 << 7),
+	GF_OLDRESUMESONG	= (1 << 2),
 
-	/* First version known not to do this: 0.000.502
+	/* Applies to all versions before 0.000.502
 	** Old SCI versions used to interpret the third DrawPic() parameter inversely,
 	** with the opposite default value (obviously).
 	** Also, they used 15 priority zones from 42 to 200 instead of 14 priority
 	** zones from 42 to 190.
 	*/
-	GF_OLDGFXFUNCTIONS	= (1 << 8),
+	GF_OLDGFXFUNCTIONS	= (1 << 3),
 
-	/* First version known not to do this: 0.000.629
+	/* Applies to all versions before 0.000.629
 	** Older SCI versions had simpler code for GetTime()
 	*/
-	GF_OLDGETTIME		= (1 << 9),
+	GF_OLDGETTIME		= (1 << 4),
 
 	// ----------------------------------------------------------------------------
 
@@ -129,19 +120,19 @@
 	** SCI1 flags
 	*/
 	
-	/* First version known to do this: 1.000.200
+	/* Applies to all versions from 1.000.200 onwards
     ** In later SCI1 versions, the argument of lofs[as]
 	** instructions is absolute rather than relative.
 	*/
-	GF_LOFSABSOLUTE		= (1 << 10),
+	GF_LOFSABSOLUTE		= (1 << 5),
 
-	/* First version known to do this: 1.000.510
+	/* Applies to all versions from 1.000.510 onwards
     ** In later SCI1 versions, CanBeHere is called inversely.
 	** Also in kDisplay(), if the text would not fit on the screen, it
     ** is moved to the left and upwards until it fits.
 	** Finally, kDoSound() is different than in earlier SCI1 versions.
 	*/
-	GF_LATESCI1			= (1 << 11)
+	GF_LATESCI1			= (1 << 6)
 };
 
 class SciEngine : public Engine {
@@ -57,71 +57,62 @@
 
-	/* First version known not to do this: 0.000.490 (PQ2-new)
+	/* Applies to all versions before 0.000.490 (PQ2-new)
 	** When a new song is initialized, we store its state and
     ** resume it when the new one finishes.  Older versions completely

Modified: scummvm/trunk/engines/sci/scicore/resource.cpp
===================================================================